const fs = require('fs-extra');
const path = require('path');
const marked = require('marked');

class BlogGenerator {
    constructor(options = {}) {
        this.sourceDir = options.sourceDir || 'source';
        this.outputDir = options.outputDir || 'public';
    }

    async generate() {
        try {
            // 确保输出目录存在
            await fs.ensureDir(this.outputDir);
            
            // 生成简单的 index.html
            const indexHtml = `
                <!DOCTYPE html>
                <html>
                <head>
                    <title>My Blog</title>
                    <style>
                        body { 
                            max-width: 800px; 
                            margin: 0 auto; 
                            padding: 20px;
                            font-family: -apple-system, system-ui, sans-serif;
                        }
                    </style>
                </head>
                <body>
                    <h1>Welcome to My Blog</h1>
                    <p>Site is under construction...</p>
                </body>
                </html>
            `;
            
            await fs.writeFile(path.join(this.outputDir, 'index.html'), indexHtml);
            
            return true;
        } catch (error) {
            console.error('Generation failed:', error);
            return false;
        }
    }
}

module.exports = {
    BlogGenerator
}; 