const express = require('express');
const path = require('path');
const fs = require('fs-extra');
const { BlogGenerator } = require('./generator');

class DevServer {
    constructor(options = {}) {
        this.port = options.port || 3000;
        this.sourceDir = options.sourceDir || 'source';
        this.outputDir = options.outputDir || 'public';
        this.generator = new BlogGenerator(options);
        
        this.app = express();
    }

    setupExpress() {
        this.app.use(express.static(this.outputDir));
        
        this.app.get('*', (req, res) => {
            const filePath = path.join(this.outputDir, req.path === '/' ? 'index.html' : req.path);
            if (fs.existsSync(filePath)) {
                res.sendFile(filePath);
            } else {
                res.status(404).send('Page not found');
            }
        });
    }

    async start() {
        try {
            await this.generator.generate();
            this.setupExpress();
            
            this.app.listen(this.port, () => {
                console.log(`Development server running at http://localhost:${this.port}`);
            });

            return true;
        } catch (error) {
            console.error('Failed to start server:', error);
            throw error;
        }
    }
}

module.exports = {
    DevServer
}; 