const ejs = require('ejs');
const fs = require('fs-extra');
const path = require('path');

class TemplateManager {
    constructor(options = {}) {
        this.templatesDir = options.templatesDir || path.join(__dirname, '../../templates');
        this.defaultTemplate = options.defaultTemplate || 'default';
    }

    async render(template, data) {
        try {
            const templatePath = path.join(this.templatesDir, `${template}.ejs`);
            
            // 如果模板文件不存在，使用内联模板
            if (!await fs.pathExists(templatePath)) {
                return this.renderInlineTemplate(data);
            }

            const templateContent = await fs.readFile(templatePath, 'utf-8');
            return ejs.render(templateContent, data);
        } catch (error) {
            console.error('Template rendering failed:', error);
            return this.renderInlineTemplate(data);
        }
    }

    renderInlineTemplate(data) {
        // 简单的内联模板
        const template = `
            <!DOCTYPE html>
            <html>
            <head>
                <meta charset="UTF-8">
                <title><%= title %></title>
                <style>
                    body {
                        max-width: 800px;
                        margin: 0 auto;
                        padding: 20px;
                        font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, sans-serif;
                        line-height: 1.6;
                    }
                    img { max-width: 100%; height: auto; }
                    pre { background: #f6f8fa; padding: 1em; overflow: auto; }
                    code { font-family: monospace; }
                </style>
            </head>
            <body>
                <header>
                    <h1><%= title %></h1>
                    <% if (date) { %>
                        <time><%= new Date(date).toLocaleDateString() %></time>
                    <% } %>
                </header>
                <main>
                    <%- content %>
                </main>
                <footer>
                    <p>Powered by Zeox</p>
                </footer>
            </body>
            </html>
        `;

        return ejs.render(template, data);
    }
}

module.exports = TemplateManager; 